# Kawhi

A package inspired by Kawhi Leonard of the Toronto Raptors.

## Usage

pip install Kawhi

``` python
from kawhi import say_hello, kawhi_joke

# Generate Hello Kawhi, this is John
say_hello('John')

# Get a Kawhi joke (with his signature laugh)
kawhi_joke()
```
